@@ -23,10 +23,18 @@
 #' 
 #' @export
 checkX13 <- function(fail = FALSE, fullcheck = TRUE, htmlcheck = TRUE){
+
+  if (fullcheck){
+    if (identical(Sys.getenv("X13_PATH"), (x13binary::x13path()))){
+      message("seasonal is using the X-13 binaries provided by x13binary")
+    }
+  }
+
   ### check path
   no.path.message <- "No path to the binary executable of X-13 specified.
   \nFor installation details, consider Section 2 of the package vignette:\n  http://cran.r-project.org/web/packages/seasonal/vignettes/seas.pdf\n"
   env.path <- Sys.getenv("X13_PATH")
+
   if (env.path == ""){
     if (fail){
       message(no.path.message)
@@ -88,7 +96,6 @@ checkX13 <- function(fail = FALSE, fullcheck = TRUE, htmlcheck = TRUE){
   if (fullcheck){
     has.failed <- FALSE
     message("X-13 installation test:")
-
     message("  - X13_PATH correctly specified")
     message("  - binary executable file found")
 
@@ -114,7 +121,7 @@ checkX13 <- function(fail = FALSE, fullcheck = TRUE, htmlcheck = TRUE){
       dir.create(wdir)
     }
     file.remove(list.files(wdir, full.names = TRUE))
-    testfile <- file.path(path.package("seasonal"), "tests", "Testairline.spc")
+    testfile <- system.file("tests", "Testairline.spc", package="seasonal")
     file.copy(testfile, wdir)
     try(run_x13(file.path(wdir, "Testairline"), out = TRUE), silent = TRUE)
 
